@@ -42,7 +42,7 @@
 #include "rendering/render_object.h"
 #include "dom/dom_exception.h"
 
-#include <QDebug>
+#include "khtml_debug.h"
 #include <QDBusConnection>
 #include <kcookiejar_interface.h>
 
@@ -57,8 +57,8 @@ using namespace khtml;
 HTMLDocumentImpl::HTMLDocumentImpl(KHTMLView *v)
     : DocumentImpl(v)
 {
-//    qDebug() << "HTMLDocumentImpl constructor this = " << this;
-    htmlElement = 0;
+//    qCDebug(KHTML_LOG) << "HTMLDocumentImpl constructor this = " << this;
+    htmlElement = nullptr;
 
     m_doAutoFill = false;
     m_determineParseMode = false;
@@ -106,7 +106,7 @@ DOMString HTMLDocumentImpl::cookie() const
     QDBusReply<QString> reply = kcookiejar.findDOMCookies(URL().url(), qlonglong(windowId));
 
     if (!reply.isValid()) {
-        qWarning() << "Can't communicate with cookiejar!";
+        qCWarning(KHTML_LOG) << "Can't communicate with cookiejar!";
         return DOMString();
     }
 
@@ -165,7 +165,7 @@ ElementImpl *HTMLDocumentImpl::createElement(const DOMString &name, int *pExcept
 {
     if (pExceptioncode && !Element::khtmlValidQualifiedName(name)) {
         *pExceptioncode = DOMException::INVALID_CHARACTER_ERR;
-        return 0;
+        return nullptr;
     }
 
     return createHTMLElement(name, hMode != XHtml);
@@ -196,7 +196,7 @@ HTMLMapElementImpl *HTMLDocumentImpl::getMap(const DOMString &_url)
     QString url = _url.string();
     QString s;
     int pos = url.indexOf('#');
-    //qDebug() << "map pos of #:" << pos;
+    //qCDebug(KHTML_LOG) << "map pos of #:" << pos;
     s = QString(_url.unicode() + pos + 1, _url.length() - pos - 1);
 
     QMap<QString, HTMLMapElementImpl *>::const_iterator it = mapMap.constFind(s);
@@ -204,7 +204,7 @@ HTMLMapElementImpl *HTMLDocumentImpl::getMap(const DOMString &_url)
     if (it != mapMap.constEnd()) {
         return *it;
     } else {
-        return 0;
+        return nullptr;
     }
 }
 
@@ -237,7 +237,7 @@ void HTMLDocumentImpl::close()
         // the first(IE)/last(Moz/Konq) registered onload on a <frame> and the
         // first(IE)/last(Moz/Konq) registered onload on a <frameset>.
 
-        //qDebug() << "dispatching LOAD_EVENT on document " << document() << " " << (view()?view()->part()->name():0);
+        //qCDebug(KHTML_LOG) << "dispatching LOAD_EVENT on document " << document() << " " << (view()?view()->part()->name():0);
 
         //Make sure to flush any pending image events now, as we want them out before the document's load event
         dispatchImageLoadEventsNow();
@@ -254,7 +254,7 @@ void HTMLDocumentImpl::close()
 void HTMLDocumentImpl::determineParseMode()
 {
     m_determineParseMode = true;
-    if (m_doctype == 0) {
+    if (m_doctype == nullptr) {
         // Currently we haven't got any doctype, so default to quirks mode and Html4
         changeModes(Compat, Html4);
     }
@@ -279,14 +279,14 @@ void HTMLDocumentImpl::changeModes(ParseMode newPMode, HTMLMode newHMode)
     m_styleSelector->strictParsing = !inCompatMode();
 
 #if 0
-    qDebug() << "DocumentImpl::determineParseMode: publicId =" << publicID << " systemId = " << systemID;
-    qDebug() << "DocumentImpl::determineParseMode: htmlMode = " << hMode;
+    qCDebug(KHTML_LOG) << "DocumentImpl::determineParseMode: publicId =" << publicID << " systemId = " << systemID;
+    qCDebug(KHTML_LOG) << "DocumentImpl::determineParseMode: htmlMode = " << hMode;
     if (pMode == Strict) {
-        qDebug() << " using strict parseMode";
+        qCDebug(KHTML_LOG) << " using strict parseMode";
     } else if (pMode == Compat) {
-        qDebug() << " using compatibility parseMode";
+        qCDebug(KHTML_LOG) << " using compatibility parseMode";
     } else {
-        qDebug() << " using transitional parseMode";
+        qCDebug(KHTML_LOG) << " using transitional parseMode";
     }
 #endif
 
@@ -350,28 +350,28 @@ public:
     HTMLTextTokenizer(DOM::HTMLDocumentImpl *doc): m_doc(doc)
     {}
 
-    void begin() Q_DECL_OVERRIDE;
-    void write(const TokenizerString &str, bool appendData) Q_DECL_OVERRIDE;
+    void begin() override;
+    void write(const TokenizerString &str, bool appendData) override;
 
-    void end() Q_DECL_OVERRIDE
+    void end() override
     {
         emit finishedParsing();
     };
-    void finish() Q_DECL_OVERRIDE
+    void finish() override
     {
         end();
     };
 
     // We don't support any inline scripts here
-    bool isWaitingForScripts() const Q_DECL_OVERRIDE
+    bool isWaitingForScripts() const override
     {
         return false;
     }
-    bool isExecutingScript() const Q_DECL_OVERRIDE
+    bool isExecutingScript() const override
     {
         return false;
     }
-    void executeScriptsWaitingForStylesheets() Q_DECL_OVERRIDE {};
+    void executeScriptsWaitingForStylesheets() override {};
 private:
     DOM::HTMLDocumentImpl *m_doc;
 };
